****************
Plotter
****************

Inheritance diagram
===================

.. inheritance-diagram:: CGATReportPlugins.Plotter
   :parts: 1

Plotter
=======================

.. automodule:: CGATReportPlugins.Plotter
   :members:



